@@ -252,26 +252,23 @@ roc.test.roc <- function(roc1, roc2,
 		if (method == "delong") {
 			# delong NA to pAUC: warn + change
 			if (has.partial.auc(roc1) || has.partial.auc(roc2)) {
-				warning("Using DeLong's test for partial AUC is not supported. Using bootstrap test instead.")
-				method <- "bootstrap"
+				stop("DeLong's test is not supported for partial AUC. Use method=\"bootstrap\" instead.")
 			}
 			if (smoothing.args$roc1$smooth || smoothing.args$roc2$smooth) {
-				warning("Using DeLong's test for smoothed ROCs is not supported. Using bootstrap test instead.")
-				method <- "bootstrap"
+				stop("DeLong's test is not supported for smoothed ROCs. Use method=\"bootstrap\" instead.")
 			}
 			if (roc1$direction != roc2$direction)
 				warning("DeLong's test should not be applied to ROC curves with a different direction.")
 		}
 		else if (method == "venkatraman") {
 			if (has.partial.auc(roc1))
-				warning("Partial AUC is ignored in Venkatraman's test.")
+				stop("Partial AUC is not supported for Venkatraman's test.")
 			if (smoothing.args$roc1$smooth || smoothing.args$roc2$smooth)
-				stop("Using Venkatraman's test for smoothed ROCs is not supported.")
+				stop("Venkatraman's test is not supported for smoothed ROCs")
 			if (roc1$direction != roc2$direction)
 				warning("Venkatraman's test should not be applied to ROC curves with different directions.")
 			if (alternative != "two.sided") {
-				warning("Only two-sided tests are available for Venkatraman. Performing two-sided test instead.")
-				alternative <- "two.sided"
+				stop("Only two-sided tests are available for Venkatraman.")
 			}
 		}
 	}
